import React from 'react';
import styled from 'styled-components';
import Paper from '@material-ui/core/Paper';
import Grid from '@material-ui/core/Grid';
import TextField from '@material-ui/core/TextField';
import MenuItem from '@material-ui/core/MenuItem';

export default function HeaderFilters({ options, contrast, orders, currOption, currOrder, handleChangeOption, handleChangeOrder }) {

  if (currOption !== 'User')
    return (
      <FiltersPaper contrast={contrast} elevation={4} square>
        <Grid className="gridStyle" container direction='row' alignItems='center'>
          <Grid item xs={12} sm={6}>
            <Grid container alignItems='center'>
              <Grid item xs={12} md={2}>
                <Label contrast={contrast}>
                  Buscar por:
                </Label>
              </Grid>
              <Grid item xs={12} md={10}>
                <StyledTextField
                  contrast={contrast}
                  select
                  fullWidth
                  value={currOption}
                  onChange={handleChangeOption}
                  variant="outlined"
                >
                  {options.map((option) => (
                    <StyledMenuItem
                      contrast={contrast}
                      key={option.value}
                      value={option.name}
                      name={option.value}
                    >
                      <span style={currOption === option.name ? { color: option.color, textDecoration: "none", fontWeight: "500" } : { color: option.color, textDecoration: "underline", fontWeight: "lighter" }}>
                        {option.value}
                      </span>
                    </StyledMenuItem>
                  ))}
                </StyledTextField>
              </Grid>
            </Grid>
          </Grid>

          <Grid item xs={12} sm={6}>
            <Grid container alignItems='center'>
              <Grid item xs={12} md={2}>
                <Label contrast={contrast}>
                  Ordenar por:
                </Label>
              </Grid>
              <Grid item xs={12} md={10}>
                <StyledTextField
                  contrast={contrast}
                  select
                  fullWidth
                  value={currOrder}
                  onChange={handleChangeOrder}
                  variant="outlined"
                >
                  {orders.map((option) => (
                    <StyledMenuItem
                      contrast={contrast}
                      color={option.color}
                      key={option.value}
                      value={option.name}
                      name={option.value}
                    >
                      <span style={currOrder === option.name ? { color: option.color, textDecoration: "none", fontWeight: "500" } : { color: option.color, textDecoration: "underline", fontWeight: "lighter" }}>
                        {option.value}
                      </span>
                    </StyledMenuItem>
                  ))}
                </StyledTextField>
              </Grid>
            </Grid>
          </Grid>
        </Grid >
      </FiltersPaper >
    )
  else
    return (
      <FiltersPaper contrast={contrast} elevation={4} square>
        <Grid className="gridStyle" container direction='row' alignItems='center'>
          <Grid item xs={12}>
            <Grid container alignItems='center'>
              <Grid item xs={12} md={2}>
                <Label contrast={contrast}>
                  Buscar por:
                </Label>
              </Grid>
              <Grid item xs={12} md={10}>
                <StyledTextField
                  contrast={contrast}
                  select
                  fullWidth
                  value={currOption}
                  onChange={handleChangeOption}
                  variant="outlined"
                >
                  {options.map((option) => (
                    <StyledMenuItem
                      contrast={contrast}
                      color={option.color}
                      key={option.value}
                      value={option.name}
                      name={option.value}
                    >
                      <span style={currOption === option.name ? { color: option.color, textDecoration: "none", fontWeight: "500" } : { color: option.color, textDecoration: "underline", fontWeight: "lighter" }}>
                        {option.value}
                      </span>
                    </StyledMenuItem>
                  ))}
                </StyledTextField>
              </Grid>
            </Grid>
          </Grid>
        </Grid>
      </FiltersPaper >
    )
}

const Label = styled.p`
  text-align: center;
  font-weight: 600; 
  color: ${props => props.contrast === "" ? "" : "white"};
`

const StyledTextField = styled(TextField)`
.MuiOutlinedInput-root {
      &.Mui-focused fieldset {
        border-color: ${props => props.contrast === "" ? "#00bcd4" : "yellow"};
      }
      fieldset {
        border-color: ${props => props.contrast === "" ? "#666" : "white"};
      }
    }
`

const StyledMenuItem = styled(MenuItem)`  
  background: ${props => props.contrast === "" ? "" : "black !important"};
`

const FiltersPaper = styled(Paper)`
  text-align: center;
  margin-top: 5px;
  margin-bottom: 30px;
  color: ${props => props.contrast === "" ? "#666" : "white"};
  border: ${props => props.contrast === "" ? 0 : "1px solid white"};

  .textInfo{
    text-align: start;
  }

  .gridStyle{
    padding: 0.5em 1em; 
    background: ${props => props.contrast === "" ? "#fff" : "black"};
  }
`;