/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useContext } from 'react'
import Paper from '@material-ui/core/Paper';
import FormInput from "../../FormInput.js"
import { CompletarCadastroButton } from './PanelSolicitarContaProfessor.js'
import { ButtonCancelar } from './PanelEditarPerfil.js'
import ValidateUserInput from '../../HelperFunctions/FormValidationFunction.js'
import ModalExcluirConta from './ModalExcluirConta.js'
import { Store } from '../../../Store'

export default function TabPanelGerenciarConta(props) {
    const { state } = useContext(Store)
    const [senhaAtual, setSenhaAtual] = useState(
        {
            key: false,
            value: localStorage.getItem("@portalmec/senha") || ""
        })

    const [novaSenha, setNovaSenha] = useState(
        {
            key: false,
            value: ""
        })

    const [novaSenhaConfirmacao, setNovaSenhaConfirmacao] = useState(
        {
            key: false,
            value: ""
        })

    const [novoEmail, setNovoEmail] = useState(
        {
            key: false,
            value: ""
        })

    const handleChangeSenha = (e, type) => {
        const userInput = e.target.value
        const flag = (type === 'confirmacao' ? ValidateUserInput('confirmation', userInput, novaSenha.value) : ValidateUserInput('password', userInput))

        if (type === 'senhaAtual') {
            setSenhaAtual({
                ...senhaAtual,
                key: flag,
                value: userInput
            })
        }
        else if (type === 'novaSenha') {
            setNovaSenha({
                ...novaSenha,
                key: flag,
                value: userInput
            })
        }
        else if (type === 'confirmacao') {
            setNovaSenhaConfirmacao({
                ...novaSenhaConfirmacao,
                key: flag,
                value: userInput
            })
        }
    }

    const handleChangeEmail = (e) => {
        const userInput = e.target.value
        const flag = ValidateUserInput('email', userInput)

        setNovoEmail({
            ...novoEmail,
            key: flag,
            value: userInput
        })

    }

    const limpaCamposForm = () => {
        setSenhaAtual({
            ...senhaAtual,
            key: false,
            value: ''
        })

        setNovaSenha({
            ...novaSenha,
            key: false,
            value: ''
        })

        setNovaSenhaConfirmacao({
            ...novaSenhaConfirmacao,
            key: false,
            value: ''
        })
    }

    const onSubmit = (e, type) => {
        e.preventDefault()

        if (type === 'senha') {
            if (!(senhaAtual.key || novaSenha.key || novaSenhaConfirmacao.key)) {
                const info = { user: { password: novaSenha.value } }
                props.updateUserPassword(info)

                limpaCamposForm()
            }
        }
        else {
            const info = { user: { email: novoEmail.value } }

            props.updateUserEmail(info)

        }

    }

    const [modalExcluir, setModalExcluir] = useState(false)

    return (
        <>
            <Paper elevation={3} style={{ width: "100%" }}>
                <div className='card-config'>
                    <div className='content-div'>
                        <h1 className="title">Gerenciar Conta</h1>
                        <div style={{ display: "flex", flexDirection: "column" }}>
                            <form style={{ margin: "0 0 20px 0" }} onSubmit={e => onSubmit(e, 'senha')}>
                                <h4 className="subtitle">Alterar Senha</h4>
                                <FormInput
                                    contrast={state.contrast}
                                    inputType={"password"}
                                    name={"Senha Atual"}
                                    value={senhaAtual.value}
                                    placeholder={"Senha atual"}
                                    handleChange={e => handleChangeSenha(e, 'senhaAtual')}
                                    required={true}
                                    error={senhaAtual.key}
                                    help={senhaAtual.key ? "Faltou inserir sua senha atual" : ""}
                                />
                                <FormInput
                                    contrast={state.contrast}
                                    inputType={"password"}
                                    name={"Nova senha"}
                                    value={novaSenha.value}
                                    placeholder={"Nova senha"}
                                    handleChange={e => handleChangeSenha(e, 'novaSenha')}
                                    required={true}
                                    error={novaSenha.key}
                                    help={novaSenha.key ? (novaSenha.value.length === 0 ? "Faltou definir uma nova senha" : "A senha precisa ter no mínimo 8 caracteres.") : ""}
                                />
                                <FormInput
                                    contrast={state.contrast}
                                    inputType={"password"}
                                    name={"Digite novamente a nova senha"}
                                    value={novaSenhaConfirmacao.value}
                                    placeholder={"Digite novamente a nova senha"}
                                    handleChange={e => handleChangeSenha(e, 'confirmacao')}
                                    required={true}
                                    error={novaSenhaConfirmacao.key}
                                    help={novaSenhaConfirmacao.key ? "As senhas devem ser iguais" : ""}
                                />
                                <div style={{ display: "flex", flexDirection: "row", justifyContent: "space-evenly" }}>
                                    <span style={{ paddingTop: "0.7em" }}><a href="recuperar-senha" className="link">Esqueceu a senha?</a></span>
                                    <div style={{ margin: "0" }}>
                                        <ButtonCancelar contrast={state.contrast} onClick={limpaCamposForm}>Limpar Campos</ButtonCancelar>
                                        <CompletarCadastroButton contrast={state.contrast} type="submit">Alterar Senha</CompletarCadastroButton>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </Paper>
            <Paper elevation={3} style={{ width: "100%" }}>
                <div className='card-config'>
                    <div className='content-div'>
                        <div style={{ display: "flex", flexDirection: "column" }}>
                            <form onSubmit={(e) => onSubmit(e, 'email')}>
                                <h4 className="subtitle">Alterar e-mail</h4>
                                <FormInput
                                    contrast={state.contrast}
                                    inputType={"text"}
                                    name={"email"}
                                    value={novoEmail.value}
                                    placeholder={"E-mail"}
                                    handleChange={e => handleChangeEmail(e)}
                                    required={true}
                                    error={novoEmail.key}
                                />
                                <div style={{ margin: "0", display: "flex", justifyContent: "flex-start" }}>
                                    <CompletarCadastroButton contrast={state.contrast} type="submit">SALVAR ALTERAÇÕES</CompletarCadastroButton>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </Paper>
            <Paper elevation={3} style={{ width: "100%" }}>
                <div className='card-config'>
                    <div className='content-div'>
                        <div>
                            <h4 className="subtitle">Conta</h4>
                            <span style={state.contrast === "" ? { margin: "0", display: "flex", justifyContent: "flex-start" } : { margin: "0", display: "flex", justifyContent: "flex-start", color: "white" }}>Antes de excluir a sua conta, saiba que ela será removida permanentemente.</span>
                        </div>
                        <div style={{ margin: "0", display: "flex", justifyContent: "flex-start" }}>
                            <ModalExcluirConta open={modalExcluir} handleClose={() => { setModalExcluir(false) }} />
                            <ButtonCancelar contrast={state.contrast} onClick={() => { setModalExcluir(true) }}>EXCLUIR CONTA</ButtonCancelar>
                        </div>
                    </div>
                </div>
            </Paper>
        </>
    )
}
